package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.ElecLoadIndex;

/**
 * 电力负荷设施指标Service接口
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
public interface IElecLoadIndexService
{
    /**
     * 查询电力负荷设施指标
     * 
     * @param id 电力负荷设施指标主键
     * @return 电力负荷设施指标
     */
     ElecLoadIndex selectElecLoadIndexById(Long id);

    /**
     * 查询电力负荷设施指标列表
     * 
     * @param emsElecLoadIndex 电力负荷设施指标
     * @return 电力负荷设施指标集合
     */
     List<ElecLoadIndex> selectElecLoadIndexList(ElecLoadIndex emsElecLoadIndex);

    /**
     * 新增电力负荷设施指标
     * 
     * @param emsElecLoadIndex 电力负荷设施指标
     * @return 结果
     */
     int insertElecLoadIndex(ElecLoadIndex emsElecLoadIndex);

    /**
     * 修改电力负荷设施指标
     * 
     * @param emsElecLoadIndex 电力负荷设施指标
     * @return 结果
     */
     int updateElecLoadIndex(ElecLoadIndex emsElecLoadIndex);

    /**
     * 批量删除电力负荷设施指标
     * 
     * @param ids 需要删除的电力负荷设施指标主键集合
     * @return 结果
     */
     int deleteElecLoadIndexByIds(Long[] ids);

    /**
     * 删除电力负荷设施指标信息
     * 
     * @param id 电力负荷设施指标主键
     * @return 结果
     */
     int deleteElecLoadIndexById(Long id);
}
